Date: 08 20, 2001 3:35:57 PM

# Opening Analyzers

There are several ways to open an analyzer project.

To open an analyzer, using Open Analyzer:

1. From the File menu, select Open Analyzer.

2. In the Open dialog, navigate to the drive and the folder containing the .ana file.

3. Select the .ana file and click Open.

To open an analyzer, using Recent Analyzers:

1. From the File menu, select Recent Analyzers.

2. Select the analyzer name from the drop-down list. (Analyzer names in the drop-down list do not contain the .ana extension.)

Note: If you already have an analyzer open, using Open Analyzer or Recent Analyzers will close the currently loaded analyzer. If the current analyzer has not been saved, you will be prompted to save the analyzer before the analyzer is loaded.

Tip: You can also set the preferences to open the last analyzer loaded when the program is launched by checking "Auto Load Last Analyzer" in the General Tab of the Preferences box.

## See Also

Load Compiled KB Preference

Saving Analyzers

Closing Analyzers